@@ -64,11 +64,11 @@ class Dns:
             self.port_mapper.remove(service.port)
 
     def full_name(self):
-        return 'device.{}'.format(self.short_name())
-
-    def short_name(self):
         domain_config = self.domain_config.load()
-        return '{}.{}'.format(domain_config.user_domain, self.main_domain_name)
+        return 'device.{}.{}'.format(domain_config.user_domain, self.main_domain_name)
+
+    def user_domain(self):
+        return self.domain_config.load().user_domain
 
     def service_info(self, name):
         service = self.get_service(name)
